@@ -1,6 +1,6 @@
 """ Test for the evaluation of the ahb expression conditions tests (Mussfeldprüfung) """
 
-from unittest.mock import Mock
+from unittest.mock import AsyncMock
 
 import inject
 import pytest
@@ -18,8 +18,8 @@ class TestAHBExpressionEvaluation:
     @pytest.fixture()
     def setup_and_teardown_injector(self):
         inject.clear_and_configure(
-            lambda binder: binder.bind(HintsProvider, Mock(wraps=HintsProvider)).bind(
-                RcEvaluator, Mock(wraps=RcEvaluator)
+            lambda binder: binder.bind(HintsProvider, AsyncMock(wraps=HintsProvider)).bind(
+                RcEvaluator, AsyncMock(wraps=RcEvaluator)
             )
         )
         yield
